@@ -862,39 +862,39 @@ public interface Session {
      * 
      * @return
      */
-    public int getFolderIdLengthLimit();
+    int getFolderIdLengthLimit();
 
     /**
      * Sets the folder id length limit for this session.
      * 
      * @return
      */
-    public void setFolderIdLengthLimit(int limit);
+    void setFolderIdLengthLimit(int limit);
 
     /**
      * Sets the current client ip address.
      * 
      * @param ip
      */
-    public void setClientIp(String ip);
+    void setClientIp(String ip);
 
     /**
      * Retrieves the current saved client ip address.
      * 
      * @return
      */
-    public String getClientIp();
+    String getClientIp();
 
     /**
      * Resets the current client ip address in the local and server session.
      * 
      * @param ip
      */
-    public void resetClientIp(String ip);
+    void resetClientIp(String ip);
 
-    public Map<String, String> getXRequestHeaders();
+    Map<String, String> getXRequestHeaders();
 
-    public void setXRequestHeaders(Map<String, String> xHeaders);
+    void setXRequestHeaders(Map<String, String> xHeaders);
 
     /**
      * Gets the newest known timestamp for the folder.
@@ -902,7 +902,7 @@ public interface Session {
      * @param folderID
      * @return
      */
-    public long getNewestTimestamp(String folderID);
+    long getNewestTimestamp(String folderID);
 
     /**
      * Invalidates any locally cached data for the current state in the OX server to make sure the next sync uses the data currently stored
@@ -910,5 +910,24 @@ public interface Session {
      * 
      * @param folderID null or empty String for folder hierarchy, folder-id for the content of a given folder
      */
-    public void invalidateCachedData(String folderID);
+    void invalidateCachedData(String folderID);
+
+    /**
+     * Tries to acquire a lock for the given ID. If successful, returns null. If not successful, returns the String that was provided as
+     * "acquirer" parameter by the instance that acquired the key and currently owns it. unlock() must be called to free the lock, or it
+     * will be blocked indefinitely.
+     * 
+     * @param id lock to acquire
+     * @param acquirer Text that will be stored and given as notification for anyone else that tries to acquire the key while it is locked.
+     * @return null if successful, else "acquirer" parameter of locker.
+     */
+    String tryLock(String id, String acquirer);
+
+    /**
+     * Unlocks a (previously acquired) lock by its id. Must be calles after the synchronous action is finished or the lock will never be
+     * freed.
+     * 
+     * @param id
+     */
+    void unlock(String id);
 }
