@@ -65,6 +65,7 @@ import org.json.JSONObject;
 import com.openexchange.usm.api.contenttypes.AppointmentContentType;
 import com.openexchange.usm.api.contenttypes.ContentTypeField;
 import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
+import com.openexchange.usm.api.contenttypes.UnsupportedContentOperationException;
 import com.openexchange.usm.api.datatypes.DataTypes;
 import com.openexchange.usm.api.exceptions.InternalUSMException;
 import com.openexchange.usm.api.exceptions.OXCommunicationException;
@@ -148,23 +149,7 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
 		parameters.put(UtilConstants.RECURRENCE_MASTER, Boolean.TRUE.toString());
 
 		JSONResult jsonResult = _ajaxAccess.doGet(getOXAjaxAccessPath(), UtilConstants.ACTION_ALL, session, parameters);
-		JSONArray jArray = extractArrayResult(jsonResult);
-		List<DataObject> resultList = new ArrayList<DataObject>();
-		for (int i = 0; i < jArray.length(); i++) {
-			JSONArray columnsArray;
-			DataObject destination = null;
-			try {
-				columnsArray = jArray.getJSONArray(i);
-				destination = _contentType.newDataObject(session);
-				updateDataObjectFromJSONArray(destination, requestedFields, columnsArray);
-				resultList.add(destination);
-			} catch (JSONException e) {
-				throw generateException(USMContentTypesUtilErrorCodes.DATA_NOT_PRESENT_NUMBER1, destination,
-						"get new appointmets:data not present", e);
-			}
-		}
-		DataObject[] result = resultList.toArray(new DataObject[resultList.size()]);
-		resetRecurrenceTypeBasedFields(result);
+		DataObject[] result = buildResultArray(session, requestedFields, jsonResult);
 		return result;
 	}
 
@@ -216,6 +201,41 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
 		resetRecurrenceTypeBasedFields(result);
 		return result;
 	}
+	
+    public DataObject[] getAllChangeExceptions(Session session, BitSet requestedFields, DataObject seriesObject) throws USMException {
+        if (_journal.isDebugEnabled())
+            _journal.debug(session + " Getting all change exceptions for series object: " + seriesObject.getID());
+        Map<String, String> parameters = new HashMap<String, String>();
+        parameters.put(UtilConstants.COLUMNS, createColumnsParameter(requestedFields));
+        parameters.put(UtilConstants.FOLDER, seriesObject.getParentFolderID());
+        parameters.put(UtilConstants.ID, seriesObject.getID());
+
+        JSONResult jsonResult = _ajaxAccess.doGet(getOXAjaxAccessPath(), CalendarConstants.GET_CHANGE_EXCEPTIONS_ACTION, session, parameters);
+        DataObject[] result = buildResultArray(session, requestedFields, jsonResult);
+        return result;
+    }
+    
+
+    private DataObject[] buildResultArray(Session session, BitSet requestedFields, JSONResult jsonResult) throws OXCommunicationException, InternalUSMException {
+        JSONArray jArray = extractArrayResult(jsonResult);
+        List<DataObject> resultList = new ArrayList<DataObject>();
+        for (int i = 0; i < jArray.length(); i++) {
+            JSONArray columnsArray;
+            DataObject destination = null;
+            try {
+                columnsArray = jArray.getJSONArray(i);
+                destination = _contentType.newDataObject(session);
+                updateDataObjectFromJSONArray(destination, requestedFields, columnsArray);
+                resultList.add(destination);
+            } catch (JSONException e) {
+                throw generateException(USMContentTypesUtilErrorCodes.DATA_NOT_PRESENT_NUMBER1, destination,
+                        "get new appointmets:data not present", e);
+            }
+        }
+        DataObject[] result = resultList.toArray(new DataObject[resultList.size()]);
+        resetRecurrenceTypeBasedFields(result);
+        return result;
+    }
 
 	@Override
 	public void writeDeletedDataObject(DataObject object) throws USMException {
