@@ -101,21 +101,11 @@ public class ContactContentTypeTransferHandler extends AbstractTransferHandler {
 	private static final String EMAIL_AUTO_COMPLETE = "emailAutoComplete";
 	// The field "image1" is a complex element that is represented by several fields in OX.
 	// This String determines which extra columns have to be fetched on a folder read.
-	private static final String EXTRA_IMAGE_COLUMNS = ",597,606,601";
+	private static final String IMAGE_COLUMNS = "597,606,601";
 	private static final String ACTION_SEARCH = "search";
 
-	private final int _image1FieldIndex;
-
 	public ContactContentTypeTransferHandler(ContactContentType contentType, Log log, OXJSONAccess ajaxAccess) {
 		super(contentType, log, ajaxAccess);
-		ContentTypeField[] fields = contentType.getFields();
-		for (int i = 0; i < fields.length; i++) {
-			if (ImageDataType.IMAGE1.equals(fields[i].getFieldName())) {
-				_image1FieldIndex = i;
-				return;
-			}
-		}
-		throw new IllegalStateException("No image1 field in ContactContentType");
 	}
 
 	@Override
@@ -276,11 +266,13 @@ public class ContactContentTypeTransferHandler extends AbstractTransferHandler {
 		return null; // one quarter of the estimate is still too big, maybe the limit is too small, return "no image" instead
 	}
 
-	@Override
-	protected void appendExtraColumns(StringBuilder columns, int i) {
-		if (i == _image1FieldIndex)
-			columns.append(EXTRA_IMAGE_COLUMNS);
-	}
+    @Override
+    protected void appendColumns(StringBuilder columns, ContentTypeField field) {
+        if (field.getFieldID() == ContactContentTypeImpl.IMAGE1_FIELD_ID)
+            columns.append(IMAGE_COLUMNS);
+        else
+            super.appendColumns(columns, field);
+    }
 
 	@Override
 	protected void updateDataObjectFromJSONArray(DataObject destination, BitSet requestedFields, JSONArray array)
@@ -291,8 +283,8 @@ public class ContactContentTypeTransferHandler extends AbstractTransferHandler {
 		for (int i = 0; i < len; i++) {
 			if (requestedFields.get(i)) {
 				updateDataObjectFieldFromJSONArray(array, j, fields[i], destination);
-				if (fields[i].getFieldName().equals(ImageDataType.IMAGE1))
-					j += 4;
+				if (fields[i].getFieldID() == ContactContentTypeImpl.IMAGE1_FIELD_ID)
+					j += 3;
 				else
 					j++;
 			}
