@@ -54,12 +54,10 @@ import java.util.BitSet;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-
 import org.apache.commons.logging.Log;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
-
 import com.openexchange.usm.api.contenttypes.ContentType;
 import com.openexchange.usm.api.contenttypes.ContentTypeField;
 import com.openexchange.usm.api.contenttypes.ContentTypeTransferHandler;
@@ -134,23 +132,23 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 					throw new UnsupportedContentOperationException(USMContentTypesUtilErrorCodes.NOT_SUPPORTED_FIELD,
 							"Field " + fields[i].getFieldName() + " is not supported");
 				}
-				if (columns.length() > 0)
-					columns.append(',');
-				columns.append(fields[i].getFieldID());
-				appendExtraColumns(columns, i);
+		        if (columns.length() > 0)
+		            columns.append(',');
+				appendColumns(columns, fields[i]);
 			}
 		}
 		return columns.toString();
 	}
 
-	/**
-	 * Adds some extra columns to the requested fields.
-	 * Content Types should implement by need.
-	 * @param columns
-	 * @param i the index
-	 */
-	protected void appendExtraColumns(StringBuilder columns, int i) {
-	}
+    /**
+     * Adds columns of a field to the requested fields. Can be overwritten by implementation for special handling of connected data.
+     * 
+     * @param columns
+     * @param field the index
+     */
+    protected void appendColumns(StringBuilder columns, ContentTypeField field) {
+        columns.append(field.getFieldID());
+    }
 
 	public void confirm(DataObject object, int response) throws AuthenticationFailedException, OXCommunicationException {
 		confirm(object, response, "");
