@@ -281,15 +281,17 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
 		return newObject;
 	}
 
-	private boolean isParentFolderShared(DataObject o) {
+	private boolean isParentFolderShared(DataObject o) throws USMJSONAPIException {
 		Folder parentFolder = o.getParentFolder();
 		if (parentFolder == null)
 			try {
 				parentFolder = _session.getCachedFolder(o.getParentFolderID());
 			} catch (DatabaseAccessException e) {
-				return false;
+				throw new USMJSONAPIException(ConnectorBundleErrorCodes.COMMAND_DB_ERROR_ON_READ_SHARED_FOLDER,
+						ResponseStatusCode.DATABASE_ERROR, "DB Access Exception on reading shared folder");
 			} catch (USMSQLException e) {
-				return false;
+				throw new USMJSONAPIException(ConnectorBundleErrorCodes.COMMAND_DB_ERROR_ON_READ_SHARED_FOLDER_1,
+						ResponseStatusCode.DATABASE_ERROR, "SQL Exception on reading shared folder");
 			}
 		if (parentFolder == null)
 			return false;
