@@ -46,20 +46,23 @@
  *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
+
 package com.openexchange.usm.connector.commands;
 
 import static com.openexchange.usm.connector.commands.CommandConstants.*;
-
 import java.util.Arrays;
-
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpSession;
-
 import org.json.JSONObject;
-
 import com.openexchange.usm.api.exceptions.USMException;
-import com.openexchange.usm.api.session.*;
-import com.openexchange.usm.json.*;
+import com.openexchange.usm.api.session.ConflictResolution;
+import com.openexchange.usm.api.session.Folder;
+import com.openexchange.usm.api.session.SlowSyncRequiredException;
+import com.openexchange.usm.api.session.SyncResult;
+import com.openexchange.usm.api.session.SynchronizationConflictException;
+import com.openexchange.usm.json.ConnectorBundleErrorCodes;
+import com.openexchange.usm.json.USMJSONAPIException;
+import com.openexchange.usm.json.USMJSONServlet;
 import com.openexchange.usm.json.response.ResponseObject;
 import com.openexchange.usm.json.response.ResponseStatusCode;
 import com.openexchange.usm.session.dataobject.DataObjectSet;
@@ -79,22 +82,31 @@ public class SyncInitHandler extends SyncCommandHandler {
 		super(servlet, httpSession, parameters, request);
 	}
 
-	@Override
-	public ResponseObject handleRequest() throws USMJSONAPIException {
-		String folderUUID = getStringParameter(FOLDERID, null);
-		readOptionalLimit();
-		ConflictResolution conflictResolution = getOptionalConflictResolution();
-		SyncResult result = computeSyncInit(folderUUID, conflictResolution);
-		initializeErrorMap(result);
-		Folder folder = null;
-		if (folderUUID != null)
-			folder = getFolderByUUID(folderUUID);
-		_cachedElements = new DataObjectSet(result.getNewState());
-		long syncId = finishProcessingAndSaveNewState(result, folder, result.getTimestamp());
-		JSONObject response = createResponseFromSyncResults(result, syncId);
-		logSyncData(" syncInit", folderUUID, 0L, syncId, result.getTimestamp());
-		return new ResponseObject(ResponseStatusCode.SUCCESS, response);
-	}
+    @Override
+    public ResponseObject handleRequest() throws USMJSONAPIException {
+        String folderUUID = getStringParameter(FOLDERID, null);
+        String lockKey = (folderUUID == null) ? "<FolderHierarchy>" : folderUUID;
+        String acquirer = "syncInit:" + lockKey;
+        String previousAcquirer = _session.tryLock(lockKey, acquirer);
+        if (previousAcquirer != null)
+            return createCannotLockFolderResponse("syncInit", "", lockKey, previousAcquirer);
+        try {
+            readOptionalLimit();
+            ConflictResolution conflictResolution = getOptionalConflictResolution();
+            SyncResult result = computeSyncInit(folderUUID, conflictResolution);
+            initializeErrorMap(result);
+            Folder folder = null;
+            if (folderUUID != null)
+                folder = getFolderByUUID(folderUUID);
+            _cachedElements = new DataObjectSet(result.getNewState());
+            long syncId = finishProcessingAndSaveNewState(result, folder, result.getTimestamp());
+            JSONObject response = createResponseFromSyncResults(result, syncId);
+            logSyncData(" syncInit", folderUUID, 0L, syncId, result.getTimestamp());
+            return new ResponseObject(ResponseStatusCode.SUCCESS, response);
+        } finally {
+            _session.unlock(lockKey);
+        }
+    }
 
 	private SyncResult computeSyncInit(String folderID, ConflictResolution conflictResolution)
 			throws USMJSONAPIException {
