@@ -48,17 +48,7 @@
  */
 package com.openexchange.usm.connector.commands;
 
-import static com.openexchange.usm.connector.commands.CommandConstants.CONFLICT_RESOLUTION;
-import static com.openexchange.usm.connector.commands.CommandConstants.CREATED;
-import static com.openexchange.usm.connector.commands.CommandConstants.DELETED;
-import static com.openexchange.usm.connector.commands.CommandConstants.FOLDERID;
-import static com.openexchange.usm.connector.commands.CommandConstants.LIMIT;
-import static com.openexchange.usm.connector.commands.CommandConstants.MODIFIED;
-import static com.openexchange.usm.connector.commands.CommandConstants.REFRESH;
-import static com.openexchange.usm.connector.commands.CommandConstants.SESSIONID;
-import static com.openexchange.usm.connector.commands.CommandConstants.SYNCID;
-import static com.openexchange.usm.connector.commands.CommandConstants.UUID_KEY;
-
+import static com.openexchange.usm.connector.commands.CommandConstants.*;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashMap;
@@ -67,13 +57,10 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.UUID;
-
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpSession;
-
 import org.json.JSONArray;
 import org.json.JSONObject;
-
 import com.openexchange.usm.api.contenttypes.ContentType;
 import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
 import com.openexchange.usm.api.database.DatabaseAccessException;
@@ -138,37 +125,45 @@ public class SyncUpdateHandler extends SyncCommandHandler {
 		super(servlet, httpSession, parameters, request);
 	}
 
-	@Override
-	public ResponseObject handleRequest() throws USMJSONAPIException {
-		String folderUUID = getStringParameter(FOLDERID, null);
-		readOptionalLimit();
-		ConflictResolution conflictResolution = getOptionalConflictResolution();
-		_syncID = getSyncID();
-		// Check if the client used an old SyncKey (repeated usage of an old syncKey indicates a problem)
-		boolean usedOldSyncKey = _session.getNewestTimestamp(_folderToSync == null ? "" : _folderToSync.getID()) > _syncID;
-		if (usedOldSyncKey) {
-			_servlet.getJournal().debug(
-					_session + " Synchronization with old sync id " + _syncID + " for folder " + folderUUID);
-		}
-		readOptionalRefreshUUIDs();
-		_syncResult = computeSyncUpdate(folderUUID, _syncID, conflictResolution);
-		initializeErrorMap(_syncResult);
-		long syncId = _syncResult.getTimestamp();
-		Folder folder = null;
-		if (folderUUID != null)
-			folder = getFolderByUUID(folderUUID);
-		if (_recurrenceUUIDMap.size() > 0 && folder != null) {
-			//make additional update to retrieve all created exception objects on the server,
-			//and replace the uuids created on the server with the original uuids sent from the client  
-			retrieveExceptionsFromServerAndSetUUIDs(syncId, folder);
-		}
-		syncId = finishProcessingAndSaveNewState(_syncResult, folder, syncId);
-		JSONObject response = createResponseFromSyncResults(_syncResult, syncId);
-		logSyncData(" syncUpdate", folderUUID, _syncID, syncId, _syncResult.getTimestamp());
-		if (usedOldSyncKey || isUnnecessaryAccess(folderUUID, response))
-			_servlet.getAccessLimiter().badAccessEncountered(_session);
-		return new ResponseObject(ResponseStatusCode.SUCCESS, response);
-	}
+    @Override
+    public ResponseObject handleRequest() throws USMJSONAPIException {
+        String folderUUID = getStringParameter(FOLDERID, null);
+        String lockKey = (folderUUID == null) ? "<FolderHierarchy>" : folderUUID;
+        String acquirer = "syncInit:" + lockKey;
+        String previousAcquirer = _session.tryLock(lockKey, acquirer);
+        if (previousAcquirer != null)
+            return createCannotLockFolderResponse("syncInit", "", lockKey, previousAcquirer);
+        try {
+            readOptionalLimit();
+            ConflictResolution conflictResolution = getOptionalConflictResolution();
+            _syncID = getSyncID();
+            // Check if the client used an old SyncKey (repeated usage of an old syncKey indicates a problem)
+            boolean usedOldSyncKey = _session.getNewestTimestamp(_folderToSync == null ? "" : _folderToSync.getID()) > _syncID;
+            if (usedOldSyncKey) {
+                _servlet.getJournal().debug(_session + " Synchronization with old sync id " + _syncID + " for folder " + folderUUID);
+            }
+            readOptionalRefreshUUIDs();
+            _syncResult = computeSyncUpdate(folderUUID, _syncID, conflictResolution);
+            initializeErrorMap(_syncResult);
+            long syncId = _syncResult.getTimestamp();
+            Folder folder = null;
+            if (folderUUID != null)
+                folder = getFolderByUUID(folderUUID);
+            if (_recurrenceUUIDMap.size() > 0 && folder != null) {
+                // make additional update to retrieve all created exception objects on the server,
+                // and replace the uuids created on the server with the original uuids sent from the client
+                retrieveExceptionsFromServerAndSetUUIDs(syncId, folder);
+            }
+            syncId = finishProcessingAndSaveNewState(_syncResult, folder, syncId);
+            JSONObject response = createResponseFromSyncResults(_syncResult, syncId);
+            logSyncData(" syncUpdate", folderUUID, _syncID, syncId, _syncResult.getTimestamp());
+            if (usedOldSyncKey || isUnnecessaryAccess(folderUUID, response))
+                _servlet.getAccessLimiter().badAccessEncountered(_session);
+            return new ResponseObject(ResponseStatusCode.SUCCESS, response);
+        } finally {
+            _session.unlock(lockKey);
+        }
+    }
 
 	private boolean isUnnecessaryAccess(String folderUUID, JSONObject response) {
 		// Check if the sync was not requested by the server, if the client sent no data and the server sent no data -> unnecessary
