@@ -333,7 +333,7 @@ public class USMJSONServlet extends HttpServlet {
                 break;
             }
             byte[] data = result.toString().getBytes(ServletConstants.UTF_ENCODING_8);
-            response.setContentType(ServletConstants.TEXT_JAVASCRIPT);
+            response.setContentType(ServletConstants.USM_JSON_CONTENT_TYPE);
             response.setContentLength(data.length);
             ServletOutputStream os = response.getOutputStream();
             if (os != null) {
