@@ -100,6 +100,7 @@ import com.openexchange.usm.session.sync.ContentSyncerSupport;
 import com.openexchange.usm.session.sync.FolderElementsStorage;
 import com.openexchange.usm.session.sync.FolderHierarchyStorage;
 import com.openexchange.usm.session.sync.OXDataCacheID;
+import com.openexchange.usm.session.sync.SynchronizationLock;
 import com.openexchange.usm.util.JSONToolkit;
 import com.openexchange.usm.util.Toolkit;
 
@@ -123,12 +124,6 @@ public class SessionImpl implements Session, Serializable {
 
     private final SessionManagerImpl _sessionManager;
 
-    private final String _user;
-
-    private final String _protocol;
-
-    private final String _device;
-
     private final List<SessionChangeListener> _changeListeners = new CopyOnWriteArrayList<SessionChangeListener>();
 
     private final Map<String, Long> _syncedFolderContent = new ConcurrentHashMap<String, Long>(16, 0.75f, 1);
@@ -146,12 +141,10 @@ public class SessionImpl implements Session, Serializable {
 
     private final OXDataCacheID _folderHierarchyCacheID;
 
-    private int _contextID;
+    private final CompleteSessionID _completeSessionID;
 
     private int _uniqueSessionID;
 
-    private int _userIdentifier;
-
     private String _defaultInboxId;
 
     private String _defaultAddress;
@@ -180,8 +173,6 @@ public class SessionImpl implements Session, Serializable {
 
     private long _lastAccessCheck = 0L;
 
-    private OXConnectionInformation _oxConnectionData;
-
     private int _folderIdLengthLimit;
 
     private String _clientIP;
@@ -194,25 +185,25 @@ public class SessionImpl implements Session, Serializable {
 
     public SessionImpl(SessionManagerImpl sessionManager, String user, String password, String protocol, String device) {
         _sessionManager = sessionManager;
-        _user = user;
         _password = password;
-        _protocol = protocol;
-        _device = device;
+        _completeSessionID = new CompleteSessionID(new SessionID(user, protocol, device), new UserID(-1, -1), null);
         _persistentData = new PersistentSessionData(this);
         _dataObjectCache = new DataObjectStorage(this);
         _folderHierarchyCacheID = new OXDataCacheID(this);
     }
 
     public void initialize(SessionInitializer initializer, JSONObject configuration) throws USMException {
+        int contextID;
+        int userIdentifier;
         try {
-            _contextID = configuration.getInt("context_id");
+            contextID = configuration.getInt("context_id");
         } catch (JSONException e) {
-            _sessionManager.getJournal().error(this + " No context_id found in initialization", e);
+            throw generateInitializationException("context_id", e);
         }
         try {
-            _userIdentifier = configuration.getInt("identifier");
+            userIdentifier = configuration.getInt("identifier");
         } catch (JSONException e) {
-            _sessionManager.getJournal().error(this + " No identifier found in initialization", e);
+            throw generateInitializationException("identifier", e);
         }
         try {
             String timeZone = configuration.getString("timezone");
@@ -222,15 +213,20 @@ public class SessionImpl implements Session, Serializable {
         } catch (JSONException e) {
             _sessionManager.getJournal().error(this + " No timezone found in initialization", e);
         }
-
+        _completeSessionID.setUserID(new UserID(contextID, userIdentifier));
         _defaultInboxId = JSONToolkit.getString(configuration, "modules", "mail", "defaultFolder", "inbox");
         _defaultAddress = JSONToolkit.getString(configuration, "modules", "mail", "defaultaddress");
-
         _persistentData.initialize(initializer, configuration);
     }
 
+    private USMException generateInitializationException(String fieldName, Throwable cause) {
+        String message = this + " No " + fieldName + " found in OX user configuration";
+        _sessionManager.getJournal().error(message, cause);
+        return new USMException(USMSessionManagementErrorCodes.SESSION_INITIALIZATION_FAILED, message);
+    }
+
     public String getUser() {
-        return _user;
+        return _completeSessionID.getSessionID().getUser();
     }
 
     public String getPassword() {
@@ -242,15 +238,15 @@ public class SessionImpl implements Session, Serializable {
     }
 
     public String getDevice() {
-        return _device;
+        return _completeSessionID.getSessionID().getDevice();
     }
 
     public String getProtocol() {
-        return _protocol;
+        return _completeSessionID.getSessionID().getProtocol();
     }
 
     public int getContextId() {
-        return _contextID;
+        return _completeSessionID.getUserID().getContextId();
     }
 
     public int getSessionId() {
@@ -262,7 +258,7 @@ public class SessionImpl implements Session, Serializable {
     }
 
     public int getUserIdentifier() {
-        return _userIdentifier;
+        return _completeSessionID.getUserID().getUserId();
     }
 
     public String getDefaultEmailAddress() {
@@ -314,11 +310,11 @@ public class SessionImpl implements Session, Serializable {
     }
 
     public EncapsulatedConnection getWritableDBConnection() throws DatabaseAccessException {
-        return _sessionManager.getDatabaseAccess().getWritable(_contextID);
+        return _sessionManager.getDatabaseAccess().getWritable(getContextId());
     }
 
     public EncapsulatedConnection getReadOnlyDBConnection() throws DatabaseAccessException {
-        return _sessionManager.getDatabaseAccess().getReadOnly(_contextID);
+        return _sessionManager.getDatabaseAccess().getReadOnly(getContextId());
     }
 
     public BitSet getFieldFilter(ContentType contentType) {
@@ -327,11 +323,11 @@ public class SessionImpl implements Session, Serializable {
 
     @Override
     public String toString() {
-        return String.valueOf(_contextID) + ':' + String.valueOf(_userIdentifier) + ':' + _user + ':' + _protocol + ':' + _device;
+        return String.valueOf(getContextId()) + ':' + String.valueOf(getUserIdentifier()) + ':' + getUser() + ':' + getProtocol() + ':' + getDevice();
     }
 
     public String getDescription() {
-        return "CID: " + _contextID + ", ID: " + _userIdentifier + ", User: " + _user + ", Protocol: " + _protocol + ", Device: " + _device;
+        return "CID: " + getContextId() + ", ID: " + getUserIdentifier() + ", User: " + getUser() + ", Protocol: " + getProtocol() + ", Device: " + getDevice();
     }
 
     public SyncResult syncChangesWithServer(String folderId, long timestamp, int resultLimit, DataObjectFilter filter, boolean storeResult, ConflictResolution conflictResolution, DataObject... elements) throws USMException {
@@ -957,9 +953,10 @@ public class SessionImpl implements Session, Serializable {
             if (result != null) {
                 // TODO Make "multiple ping mark as synchronized" workaround configurable, let protocol configure it, remove reference to
                 // EAS here
-                if (++_directPingResponses > DIRECT_PING_RESPONSE_LIMIT && "EAS".equals(_protocol)) { // fix for bug 22741 - enable the ping
-                                                                                                      // response limit ONLY for EAS
-                                                                                                      // protocol
+                if (++_directPingResponses > DIRECT_PING_RESPONSE_LIMIT && "EAS".equals(getProtocol())) { // fix for bug 22741 - enable the
+                                                                                                          // ping
+                    // response limit ONLY for EAS
+                    // protocol
                     if (journal.isDebugEnabled())
                         _sessionManager.getJournal().debug(
                             this + " Too many pings without sync, marked as synchronized: " + Arrays.toString(contentChangeParentIDsToWatch));
@@ -1216,7 +1213,7 @@ public class SessionImpl implements Session, Serializable {
     }
 
     public void storeUUID(ContentType contentType, int objectId, UUID uuid, int folderOwner) throws USMException {
-        _sessionManager.storeUUID(_contextID, contentType, objectId, uuid, (folderOwner == _userIdentifier) ? 0 : folderOwner);
+        _sessionManager.storeUUID(getContextId(), contentType, objectId, uuid, (folderOwner == getUserIdentifier()) ? 0 : folderOwner);
     }
 
     public PersistentSessionData getPersistentSessionData() {
@@ -1224,7 +1221,7 @@ public class SessionImpl implements Session, Serializable {
     }
 
     public UUID getContextUUID() throws DatabaseAccessException, USMSQLException {
-        return _sessionManager.getContextUUID(_contextID);
+        return _sessionManager.getContextUUID(getContextId());
     }
 
     public void insertStoredUUID(DataObject o) throws DatabaseAccessException, USMSQLException {
@@ -1275,11 +1272,11 @@ public class SessionImpl implements Session, Serializable {
     }
 
     public OXConnectionInformation getOXConnectionData() {
-        return _oxConnectionData;
+        return _completeSessionID.getOXConnectionInformation();
     }
 
     public void setOXConnectionData(OXConnectionInformation data) {
-        _oxConnectionData = data;
+        _completeSessionID.setOXConnectionInformation(data);
     }
 
     public OXDataCacheID getFolderHierarchyCacheID() {
@@ -1368,4 +1365,16 @@ public class SessionImpl implements Session, Serializable {
     public Lock getOXConnectionLock() {
         return _oxLock;
     }
+
+    public CompleteSessionID getCompleteSessionID() {
+        return _completeSessionID;
+    }
+
+    public String tryLock(String id, String acquirer) {
+        return SynchronizationLock.lock(this, id, acquirer);
+    }
+
+    public void unlock(String id) {
+        SynchronizationLock.unlock(this, id);
+    }
 }
