@@ -58,6 +58,7 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.UUID;
+import java.util.concurrent.atomic.AtomicInteger;
 import javax.management.MalformedObjectNameException;
 import javax.management.NotCompliantMBeanException;
 import javax.management.ObjectName;
@@ -198,7 +199,7 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
         _dataCache = new OXDataCache(0, 0);
     }
 
-    public void activate(Log log, OXJSONAccess ajaxAccess, ContentTypeManager contentTypeManager, FolderContentType folderContentType, OXEventManager oxEventManager, ConfigurationManager configurationManager, DatabaseAccess dbAccess, ObjectIdMappingService mappingService, UUIDMappingService uuidService) {
+    public void activate(Log log, OXJSONAccess ajaxAccess, ContentTypeManager contentTypeManager, FolderContentType folderContentType, OXEventManager oxEventManager, ConfigurationManager configurationManager, DatabaseAccess dbAccess, ObjectIdMappingService mappingService, UUIDMappingService uuidService, TimerService timerService) {
         _journal = log;
         _oxAjaxAccess = ajaxAccess;
         _contentTypeManager = contentTypeManager;
@@ -208,6 +209,7 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
         _databaseAccess = dbAccess;
         _mappingService = mappingService;
         _uuidService = uuidService;
+        _timerService = timerService;
         try {
             _syncRetryCount = _configurationManager.getProperty(
                 ConfigurationProperties.SYNC_CONCURRENT_MODIFICATION_MAX_RETRIES_PROPERTY,
@@ -346,6 +348,7 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
         _sessionStorage = new SessionStorage(this);
         _dataCache = new OXDataCache(cacheTimeLimitSyncComplete, cacheTimeLimitSyncIncomplete);
         _oxEventManager.addEventListener(this);
+        setTimerService(_timerService); // Initialize timers if TimerService was already set
 
         _journal.info("USM SessionManager activated");
         _journal.info("Open-Xchange USM Version " + USMVersion.VERSION + " (Build " + USMVersion.BUILD_NUMBER + ") successfully started");
@@ -356,6 +359,7 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
     }
 
     public void deactivate() {
+        deactivateTimers();
         _oxEventManager.removeEventListener(this);
         _sessionStorage.shutdown(_oxAjaxAccess);
         _configurationManager = null;
@@ -439,7 +443,7 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
         checkUSMAccess(session, configuration);
         session.setLastAccessCheck(System.currentTimeMillis());
         session.initialize(initializer, configuration);
-        _sessionStorage.storeSession(id, session);
+        _sessionStorage.storeSession(session);
         _usmCacheInformation.newSessionCreated();
         session.setPersistentField(LAST_ACCESS_FIELD_NAME, String.valueOf(System.currentTimeMillis()));
         return session;
@@ -770,7 +774,7 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
         return new IncrementalContentSyncer(this, _syncRetryCount);
     }
 
-    public void setTimerService(TimerService timerService) {
+    private void deactivateTimers() {
         if (_cleanupTask != null) {
             _cleanupTask.cancel();
             _cleanupTask = null;
@@ -779,8 +783,15 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
             _sessionCacheCleanupTask.cancel();
             _sessionCacheCleanupTask = null;
         }
-        _timerService = timerService;
-        if (_timerService != null) {
+        if (_sessionCacheCleanupLogInfoTask != null) {
+            _sessionCacheCleanupLogInfoTask.cancel();
+            _sessionCacheCleanupLogInfoTask = null;
+        }
+    }
+    
+    public void setTimerService(TimerService timerService) {
+        deactivateTimers();
+        if (_timerService != null && _configurationManager != null) { // Only start new tasks if bundle is activated and TimerService is available
             _cleanupTask = _timerService.scheduleAtFixedRate(
                 new USMSessionCleanupTask(this),
                 USMSessionCleanupTask.INITIAL_DELAY,
