@@ -80,18 +80,18 @@ public class SessionStorage {
         _sessionManager = sessionManager;
     }
 
-    public void storeSession(SessionID id, SessionImpl session) {
-        UserID userId = new UserID(session);
+    public void storeSession(SessionImpl session) {
+        SessionID id = session.getCompleteSessionID().getSessionID();
         SessionReference ref = new SessionReference(session, _referenceQueue);
         SessionReference oldRef = _map.put(id, ref);
-        _backwardsMap.put(ref.getReference(), new CompleteSessionID(id, userId, session.getOXConnectionData()));
+        _backwardsMap.put(ref.getReference(), session.getCompleteSessionID());
         if (oldRef != null)
             _backwardsMap.remove(oldRef.getReference());
-        addToUserDeviceMap(userId, id);
+        addToUserDeviceMap(session.getCompleteSessionID().getUserID(), id);
     }
 
     public void removeSession(SessionImpl session) {
-        SessionReference oldRef = _map.remove(new SessionID(session));
+        SessionReference oldRef = _map.remove(session.getCompleteSessionID().getSessionID());
         if (oldRef != null) {
             CompleteSessionID completeSessionId = _backwardsMap.remove(oldRef.getReference());
             if (completeSessionId != null)
@@ -167,15 +167,16 @@ public class SessionStorage {
      * 
      * @return number of SessionReferences that were removed
      */
-    public synchronized int removeClearedReferences() {
+    public int removeClearedReferences() {
         int count = 0;
         for (Reference<? extends SessionImpl> ref = _referenceQueue.poll(); ref != null; ref = _referenceQueue.poll()) {
             CompleteSessionID id = _backwardsMap.remove(ref);
             if (id != null) {
                 removeFromUserDeviceMap(id.getUserID(), id.getSessionID());
+                _map.remove(id.getSessionID());
                 _sessionManager.getOXAjaxAccess().logout(id.getOXConnectionInformation());
-                SessionReference oldRef = _map.remove(id.getSessionID());
-                assert (ref == oldRef.getReference());
+                // SessionReference oldRef = _map.remove(id.getSessionID());
+                // assert (ref == oldRef.getReference());
                 count++;
             }
         }
