@@ -48,11 +48,28 @@
  */
 package com.openexchange.usm.session.sync;
 
-import java.util.*;
-
+import java.util.ArrayList;
+import java.util.Comparator;
+import java.util.HashMap;
+import java.util.HashSet;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Map;
+import java.util.Set;
+import java.util.UUID;
 import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
-import com.openexchange.usm.api.exceptions.*;
-import com.openexchange.usm.api.session.*;
+import com.openexchange.usm.api.exceptions.ConflictingChange;
+import com.openexchange.usm.api.exceptions.ConflictingChangeException;
+import com.openexchange.usm.api.exceptions.InternalUSMException;
+import com.openexchange.usm.api.exceptions.USMException;
+import com.openexchange.usm.api.session.ChangeState;
+import com.openexchange.usm.api.session.ConflictResolution;
+import com.openexchange.usm.api.session.DataObject;
+import com.openexchange.usm.api.session.DataObjectFilter;
+import com.openexchange.usm.api.session.Folder;
+import com.openexchange.usm.api.session.SlowSyncRequiredException;
+import com.openexchange.usm.api.session.SyncResult;
+import com.openexchange.usm.api.session.SynchronizationConflictException;
 import com.openexchange.usm.session.dataobject.DataObjectSet;
 import com.openexchange.usm.session.dataobject.DataObjectUtil;
 import com.openexchange.usm.session.impl.SessionManagerImpl;
@@ -89,7 +106,7 @@ public class IncrementalContentSyncer extends BaseContentSyncer {
 		}
 		if (_journal.isDebugEnabled())
 			_journal.debug(storage + " Starting incremental sync, resolution=" + conflictResolution + ", timestamp="
-					+ timestamp);
+					+ timestamp + ',' + dataObjectChanges.length + " client requests");
 		for (int count = 0; count <= _retryCount; count++) {
 			if (filter != null)
 				filter.initialize();
@@ -262,7 +279,7 @@ public class IncrementalContentSyncer extends BaseContentSyncer {
 			SyncResult result = ContentSyncerSupport.storeDataObjectsAndBuildClientResult(incomplete, storage,
 					serverDataObjects, clientResults, errorMap, dataObjectChanges);
 			if (_journal.isDebugEnabled())
-				_journal.debug(storage + " Incremental sync finished");
+				_journal.debug(storage + " Incremental sync finished: " + result.getDescription());
 			return result;
 		}
 		throw new SynchronizationConflictException(USMSessionManagementErrorCodes.TOO_MANY_CONFICTS_INCR_SYNC,
